@@ -1,5 +1,5 @@
 package Statocles;
-our $VERSION = '0.079';
+our $VERSION = '0.080';
 # ABSTRACT: A static site generator
 
 # The currently-running site.
@@ -31,7 +31,7 @@ Statocles - A static site generator
 
 =head1 VERSION
 
-version 0.079
+version 0.080
 
 =head1 SYNOPSIS
 
@@ -142,7 +142,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Doug Bell Joel Berger Kent Fredric tadegenban Vladimir Lettiev William Lindley
+=for stopwords Doug Bell Ferenc Erki Joel Berger Kent Fredric tadegenban Vladimir Lettiev William Lindley
 
 =over 4
 
@@ -152,6 +152,10 @@ Doug Bell <doug@preaction.me>
 
 =item *
 
+Ferenc Erki <erkiferenc@gmail.com>
+
+=item *
+
 Joel Berger <joel.a.berger@gmail.com>
 
 =item *
