@@ -1,7 +1,8 @@
 package Statocles::App::Blog;
-our $VERSION = '0.079';
+our $VERSION = '0.080';
 # ABSTRACT: A blog application
 
+use Text::Unidecode;
 use Statocles::Base 'Class';
 use Getopt::Long qw( GetOptionsFromArray );
 use Statocles::Store;
@@ -269,7 +270,10 @@ ENDHELP
 
 sub make_slug {
     my ( $self, $slug ) = @_;
+    $slug = unidecode($slug);
+    $slug =~ s/'//g;
     $slug =~ s/[\W]+/-/g;
+    $slug =~ s/^-|-$//g;
     return lc $slug;
 }
 
@@ -635,7 +639,7 @@ Statocles::App::Blog - A blog application
 
 =head1 VERSION
 
-version 0.079
+version 0.080
 
 =head1 DESCRIPTION
 
